package api

import (
	"fmt"

	db "git.nochill.in/nochill/hiling_go/db/sqlc"
	"git.nochill.in/nochill/hiling_go/util"
	"git.nochill.in/nochill/hiling_go/util/token"
	"github.com/gin-gonic/gin"
)

type Server struct {
	config     util.Config
	store      db.Store
	tokenMaker token.Maker
	Router     *gin.Engine
}

func NewServer(config util.Config, store db.Store) (*Server, error) {
	tokenMaker, err := token.NewPasetoMaker(config.TokenSymmetricKey)
	if err != nil {
		return nil, fmt.Errorf("cannot create token maker: %w", err)
	}

	server := &Server{
		config:     config,
		store:      store,
		tokenMaker: tokenMaker,
	}

	server.getRoutes()
	return server, nil
}

func (server *Server) getRoutes() {
	router := gin.Default()

	router.POST("/user/signup", server.createUser)

	server.Router = router
}

func (server *Server) Start(address string) error {
	return server.Router.Run(address)
}
